.. _whatsnew_0001:

{{ header }}

Version 0.0.1 (May 15, 2020)
-----------------------------

Preliminary version of puffbird. It contains the main features, which include
the :obj:`puffy_to_long` function and the :obj:`FrameEngine` object.

Contributors
~~~~~~~~~~~~

* Matthias Christenson (gucky92)
